@@ -1,8 +1,13 @@
 prob.norm <- 
 function(lo=NULL, hi=NULL, mu=0, sigma=1, nrm.color="black", 
          fill.nrm="grey91", fill.int="slategray3", 
-         ylab="", y.axis=FALSE, z=TRUE, mag=.9, ...) { 
+         ylab="", y.axis=FALSE, z=TRUE, axis.size=.9,
+         pdf.file=NULL, width=5, height=5, ...) { 
 
+  if (sigma <= 0) { 
+    cat("\n"); stop(call.=FALSE, "\n","------\n",
+    "Sigma, the population standard deviation, must be larger than zero.\n\n")
+  }
 
   dots <- list(...)  # check for deprecated parameters
   if (length(dots) > 0) {
@@ -11,22 +16,22 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, nrm.color="black",
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "options that began with the abbreviation  col  now begin with  ",
           "color \n\n")
+      if (names(dots)[i] == "mag")  axis.size <- dots[[i]]
       }
     }
   }
 
-  if (sigma <= 0) { 
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-    "Sigma, the population standard deviation, must be larger than zero.\n\n")
-  }
+  if (!is.null(pdf.file))
+    if (!grepl(".pdf", pdf.file)) pdf.file <- paste(pdf.file, ".pdf", sep="")
  
-  if (mu==0  && sigma==1) z=FALSE
+  if (mu==0  && sigma==1) z <- FALSE
  
   if (is.null(lo)) {
     lo <- mu - sigma*10
     lo.lbl <- "..."
   }
-  else lo.lbl <- as.character(lo)
+  else
+    lo.lbl <- as.character(lo)
   if (is.null(hi)) {
     hi <- mu + sigma*10
     hi.lbl <- "..."
@@ -35,7 +40,12 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, nrm.color="black",
 
   
   # normal density curve
-  .graphwin(1)
+  .opendev(pdf.file, width, height)
+
+  orig.params <- par(no.readonly=TRUE)
+  par(mar=c(3,2,1.75,2), mgp=c(1,.5,0))
+
+
   min.x <- mu - 4*sigma
   max.x <- mu + 4*sigma
   cuts <- seq(min.x,max.x,sigma)
@@ -44,11 +54,11 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, nrm.color="black",
   plot(x, d.nrm, type="l", col=nrm.color, axes=FALSE, xlab="", ylab="", ...)
   polygon(c(min.x,x,max.x), c(0,d.nrm,0), col=fill.nrm)
 
-  axis(side=1, at=cuts, cex.axis=mag)
-  if (z) axis(side=1, at=cuts, cex.axis=mag, line=1.5,
+  axis(side=1, at=cuts, cex.axis=axis.size)
+  if (z) axis(side=1, at=cuts, cex.axis=axis.size, line=1.5,
               labels=-4:4, lwd=0, lwd.ticks=0)
   if (y.axis) {
-    axis(side=2, cex.axis=mag)
+    axis(side=2, cex.axis=axis.size)
     if (ylab == "") ylab="Normal Density"
     title(ylab=ylab)
   }
@@ -70,6 +80,13 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, nrm.color="black",
   lbl3 <- bquote(paste(mu, "=", .(mu), "  ", sigma, "=", .(sigma)))
   if (z) title(sub=lbl3, line=4, ...) else title(sub=lbl3, ...)
 
-  return(prob)
+  # terminate pdf graphics system
+  par(orig.params)        
+  if (!is.null(pdf.file)) {
+    dev.off()
+    .showfile(pdf.file, "Normal curve probability")
+  }
+
+  cat("Probability: ", prob, "\n")
 
 }
