@@ -368,7 +368,7 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
         col.line=getOption("pt.color"), col.area=NULL,
         col.box=getOption("panel.color"),
         col.color=getOption("pt.color"), 
-        col.fill=getOption("bar.fill"), shape.pts=21,
+        col.fill=getOption("bar.fill.ordered"), shape.pts=21,
         col.bg=getOption("panel.fill"), lab.cex=getOption("lab.cex"),
         axis.cex=0.75, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
         xy.ticks=TRUE, line.width=1.1,
@@ -394,7 +394,7 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
        col.line=getOption("pt.color"), col.area=NULL,
        col.box=getOption("panel.color"),
        col.color=getOption("pt.color"), 
-       col.fill=getOption("bar.fill"), shape.pts=21,
+       col.fill=getOption("bar.fill.ordered"), shape.pts=21,
        col.bg=getOption("panel.fill"), lab.cex=getOption("lab.cex"),
        axis.cex=0.85, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
        xy.ticks=TRUE, line.width=1.1,
